| Title: | Secreted Signaling Activity Inference |
|---|---|
| Description: | Inferring secreted protein activities at bulk, single-cell, and spatial levels. SecAct uses ridge regression with permutation-based significance testing to infer the activity of over 1000 secreted proteins from gene expression profiles. |
| Authors: | Beibei Ru [aut], Zaoqu Liu [cre, ctb] |
| Maintainer: | Zaoqu Liu <[email protected]> |
| License: | GPL-3 + file LICENSE |
| Version: | 1.0.1 |
| Built: | 2026-05-23 08:34:41 UTC |
| Source: | https://github.com/Zaoqu-Liu/SecAct |
Infer the signaling activity of 1248 secreted proteins from gene expression profiles.
SecAct.activity.inference( inputProfile, inputProfile_control = NULL, is.differential = FALSE, is.paired = FALSE, is.singleSampleLevel = FALSE, sigMatrix = "SecAct", is.group.sig = TRUE, is.group.cor = 0.9, lambda = 5e+05, nrand = 1000, sigFilter = FALSE )SecAct.activity.inference( inputProfile, inputProfile_control = NULL, is.differential = FALSE, is.paired = FALSE, is.singleSampleLevel = FALSE, sigMatrix = "SecAct", is.group.sig = TRUE, is.group.cor = 0.9, lambda = 5e+05, nrand = 1000, sigFilter = FALSE )
inputProfile |
Gene expression matrix with gene symbol (row) x sample (column). |
inputProfile_control |
Gene expression matrix with gene symbol (row) x sample (column). |
is.differential |
A logical indicating whether inputProfile has been differential profiles against to control. |
is.paired |
A logical indicating whether you want a paired operation of differential profiles between inputProfile and inputProfile_control if samples in inputProfile and inputProfile_control are paired. |
is.singleSampleLevel |
A logical indicating whether to calculate activity change for each single sample between inputProfile and inputProfile_control. If FALSE, calculate the overall activity change between two phenotypes. |
sigMatrix |
Secreted protein signature matrix. |
is.group.sig |
A logical indicating whether group similar signatures. |
is.group.cor |
Correlation cutoff of similar signatures. |
lambda |
Penalty factor in the ridge regression. |
nrand |
Number of randomization in the permutation test, with a default value 1000. |
sigFilter |
A logical indicating whether filter the secreted protein signatures with the genes from inputProfile. |
A list with four items, each is a matrix. beta: regression coefficients se: standard errors of coefficients zscore: beta/se pvalue: statistical significance
Calculate secreted protein signaling activity of cell states from single cell RNA-Sequencing data.
SecAct.activity.inference.scRNAseq( inputProfile, cellType_meta, sigMatrix = "SecAct", is.singleCellLevel = FALSE, is.group.sig = TRUE, is.group.cor = 0.9, lambda = 5e+05, nrand = 1000, sigFilter = FALSE )SecAct.activity.inference.scRNAseq( inputProfile, cellType_meta, sigMatrix = "SecAct", is.singleCellLevel = FALSE, is.group.sig = TRUE, is.group.cor = 0.9, lambda = 5e+05, nrand = 1000, sigFilter = FALSE )
inputProfile |
A Seurat object. |
cellType_meta |
Column name in meta data that includes cell-type annotations. |
sigMatrix |
Secreted protein signature matrix. |
is.singleCellLevel |
A logical indicating whether to calculate for each single cell. |
is.group.sig |
A logical indicating whether to group similar signatures. |
is.group.cor |
Correlation cutoff of similar signatures. |
lambda |
Penalty factor in the ridge regression. |
nrand |
Number of randomization in the permutation test, with a default value 1000. |
sigFilter |
A logical indicating whether filter the secreted protein signatures with the genes from inputProfile. |
A Seurat object.
Calculate secreted protein signaling activity of spots from spatial transcriptomocs data.
SecAct.activity.inference.ST( inputProfile, inputProfile_control = NULL, scale.factor = 1e+05, sigMatrix = "SecAct", is.group.sig = TRUE, is.group.cor = 0.9, lambda = 5e+05, nrand = 1000, sigFilter = FALSE )SecAct.activity.inference.ST( inputProfile, inputProfile_control = NULL, scale.factor = 1e+05, sigMatrix = "SecAct", is.group.sig = TRUE, is.group.cor = 0.9, lambda = 5e+05, nrand = 1000, sigFilter = FALSE )
inputProfile |
A SpaCET object. |
inputProfile_control |
A SpaCET object. |
scale.factor |
Sets the scale factor for spot-level normalization. |
sigMatrix |
Secreted protein signature matrix. |
is.group.sig |
A logical indicating whether to group similar signatures. |
is.group.cor |
Correlation cutoff of similar signatures. |
lambda |
Penalty factor in the ridge regression. |
nrand |
Number of randomization in the permutation test, with a default value 1000. |
sigFilter |
A logical indicating whether filter the secreted protein signatures with the genes from inputProfile. |
A SpaCET object.
Draw a bar plot of secreted proteins.
SecAct.bar.plot(fg.vec, title = NULL, colors = c("#91bfdb", "#fc8d59"))SecAct.bar.plot(fg.vec, title = NULL, colors = c("#91bfdb", "#fc8d59"))
fg.vec |
A vector of values. |
title |
The title for plot. |
colors |
Colors. |
A ggplot2 object.
Draw a circle plot of cell-cell communication mediated by secreted proteins.
SecAct.CCC.circle(data, colors_cellType, sender = NULL, receiver = NULL)SecAct.CCC.circle(data, colors_cellType, sender = NULL, receiver = NULL)
data |
A SpaCET object or a Seurat object. |
colors_cellType |
Colors for cell types. |
sender |
Sender cell types to highlight. |
receiver |
Receiver cell types to highlight. |
A circlize object.
Draw a dot plot of cell-cell communication mediated by secreted proteins.
SecAct.CCC.dot(data, sender = NULL, secretedProtein = NULL, receiver = NULL)SecAct.CCC.dot(data, sender = NULL, secretedProtein = NULL, receiver = NULL)
data |
A SpaCET object or a Seurat object. |
sender |
Sender cell types. |
secretedProtein |
Secreted proteins. |
receiver |
Receiver cell types. |
A ggplot2 object.
Draw a heatmap of cell-cell communication mediated by secreted proteins.
SecAct.CCC.heatmap( data, row.sorted = FALSE, column.sorted = FALSE, colors_cellType )SecAct.CCC.heatmap( data, row.sorted = FALSE, column.sorted = FALSE, colors_cellType )
data |
A SpaCET object or a Seurat object. |
row.sorted |
Whether to sort rows. |
column.sorted |
Whether to sort columns. |
colors_cellType |
Colors for cell types. |
A Heatmap-class object.
Draw a sankey plot of cell-cell communication mediated by secreted proteins.
SecAct.CCC.sankey( data, colors_cellType, sender = NULL, secretedProtein = NULL, receiver = NULL )SecAct.CCC.sankey( data, colors_cellType, sender = NULL, secretedProtein = NULL, receiver = NULL )
data |
A SpaCET object or a Seurat object. |
colors_cellType |
Colors for cell types. |
sender |
Sender cell types. |
secretedProtein |
Secreted proteins. |
receiver |
Receiver cell types. |
A ggplot2 object.
Calculate condition-specific cell-cell communication mediated by secreted proteins from scRNA-Seq data.
SecAct.CCC.scRNAseq( Seurat_obj, cellType_meta, condition_meta, conditionCase, conditionControl, scale.factor = 1e+05, act_diff_cutoff = 2, exp_logFC_cutoff = 0.2, exp_mean_all_cutoff = 2, exp_fraction_case_cutoff = 0.1, padj_cutoff = 0.01, sigMatrix = "SecAct", is.group.sig = TRUE, is.group.cor = 0.9, lambda = 5e+05, nrand = 1000 )SecAct.CCC.scRNAseq( Seurat_obj, cellType_meta, condition_meta, conditionCase, conditionControl, scale.factor = 1e+05, act_diff_cutoff = 2, exp_logFC_cutoff = 0.2, exp_mean_all_cutoff = 2, exp_fraction_case_cutoff = 0.1, padj_cutoff = 0.01, sigMatrix = "SecAct", is.group.sig = TRUE, is.group.cor = 0.9, lambda = 5e+05, nrand = 1000 )
Seurat_obj |
A Seurat object. |
cellType_meta |
Column name in meta data that includes cell-type annotations. |
condition_meta |
Column name in meta data that includes condition information. |
conditionCase |
Case condition. |
conditionControl |
Control condition. |
scale.factor |
Sets the scale factor for cell-level normalization in step2. |
act_diff_cutoff |
Cut off for activity change (i.e., z score) in step 1. |
exp_logFC_cutoff |
Cut off for log fold change in step 2. |
exp_mean_all_cutoff |
Cut off for mean expression across all cells. |
exp_fraction_case_cutoff |
Cut off for the fraction of cells expressing secreted protein-coding genes in step 2. |
padj_cutoff |
Adjusted p value cut off. |
sigMatrix |
Secreted protein signature matrix. |
is.group.sig |
A logical indicating whether to group similar signatures. |
is.group.cor |
Correlation cutoff of similar signatures. |
lambda |
Penalty factor in the ridge regression. |
nrand |
Number of randomization in the permutation test, with a default value 1000. |
A Seurat object.
Calculate cell-cell communication mediated by secreted proteins from spatial transcriptomics data.
SecAct.CCC.scST( SpaCET_obj, cellType_meta, scale.factor = 1000, radius = 20, ratio_cutoff = 0.2, padj_cutoff = 0.01, coreNo = 6 )SecAct.CCC.scST( SpaCET_obj, cellType_meta, scale.factor = 1000, radius = 20, ratio_cutoff = 0.2, padj_cutoff = 0.01, coreNo = 6 )
SpaCET_obj |
A SpaCET object. |
cellType_meta |
Column name in meta data that includes cell-type annotations. |
scale.factor |
Sets the scale factor for spot-level normalization. |
radius |
Radius cut off (unit: um). |
ratio_cutoff |
Ratio cut off. |
padj_cutoff |
Adjusted p value cut off. |
coreNo |
Core number in parallel computation. |
A Seurat object.
Check if SecAct data is available and show its location.
SecAct.check.data()SecAct.check.data()
Invisible logical indicating whether data is available.
SecAct.check.data()SecAct.check.data()
Calculate the risk score of each secreted protein.
SecAct.coxph.regression(mat, surv)SecAct.coxph.regression(mat, surv)
mat |
Activity matrix. |
surv |
Survival matrix. |
A matrix.
Downloads the SecAct signature matrix from GitHub Release.
SecAct.download.data(force = FALSE, timeout = 600)SecAct.download.data(force = FALSE, timeout = 600)
force |
Logical, whether to force re-download even if file exists. Default FALSE. |
timeout |
Download timeout in seconds. Default 600. |
Invisible path to the downloaded file.
## Not run: SecAct.download.data() ## End(Not run)## Not run: SecAct.download.data() ## End(Not run)
Draw a heatmap plot of secreted proteins.
SecAct.heatmap.plot( fg.mat, title = NULL, colors = c("#03c383", "#aad962", "#fbbf45", "#ef6a32") )SecAct.heatmap.plot( fg.mat, title = NULL, colors = c("#03c383", "#aad962", "#fbbf45", "#ef6a32") )
fg.mat |
A matrix of values. |
title |
The title for plot. |
colors |
Colors. |
A ggplot2 object.
Infer the activity of over 1000 secreted proteins from tumor gene expression profiles.
SecAct.inference.gsl(Y, SigMat = "SecAct", lambda = 5e+05, nrand = 1000)SecAct.inference.gsl(Y, SigMat = "SecAct", lambda = 5e+05, nrand = 1000)
Y |
Gene expression matrix with gene symbol (row) x sample (column). |
SigMat |
Secreted protein signature matrix. |
lambda |
Penalty factor in the ridge regression. |
nrand |
Number of randomization in the permutation test, with a default value 1000. |
A list with four items, each is a matrix. beta: regression coefficients se: standard errors of coefficients zscore: beta/se pvalue: statistical significance
Infer the activity of over 1000 secreted proteins from tumor gene expression profiles.
SecAct.inference.r(Y, SigMat = "SecAct", lambda = 5e+05, nrand = 1000)SecAct.inference.r(Y, SigMat = "SecAct", lambda = 5e+05, nrand = 1000)
Y |
Gene expression matrix with gene symbol (row) x sample (column). |
SigMat |
Secreted protein signature matrix. |
lambda |
Penalty factor in the ridge regression. |
nrand |
Number of randomizations in the permutation test, with a default value 1000. |
A list with four items, each is a matrix. beta: regression coefficients se: standard errors of coefficients zscore: beta/se pvalue: statistical significance
Draw a lollipop plot of secreted proteins.
SecAct.lollipop.plot(fg.vec, title = NULL)SecAct.lollipop.plot(fg.vec, title = NULL)
fg.vec |
A vector of values. |
title |
The title for plot. |
A ggplot2 object.
Calculate the signaling pattern of secreted proteins based on their activities.
SecAct.signaling.pattern(SpaCET_obj, scale.factor = 1e+05, radius = 200, k)SecAct.signaling.pattern(SpaCET_obj, scale.factor = 1e+05, radius = 200, k)
SpaCET_obj |
A SpaCET object. |
scale.factor |
Sets the scale factor for spot-level normalization. |
radius |
Radius cut off. |
k |
Number of patterns for NMF. |
A SpaCET object with pattern results.
## Not run: SpaCET_obj <- SecAct.signaling.pattern(SpaCET_obj, k=3) ## End(Not run)## Not run: SpaCET_obj <- SecAct.signaling.pattern(SpaCET_obj, k=3) ## End(Not run)
Enumerate secreted proteins associated with each signaling pattern.
SecAct.signaling.pattern.gene(SpaCET_obj, n)SecAct.signaling.pattern.gene(SpaCET_obj, n)
SpaCET_obj |
A SpaCET object. |
n |
Pattern order. |
A matrix.
## Not run: res <- SecAct.signaling.pattern.gene(SpaCET_obj, n=3) ## End(Not run)## Not run: res <- SecAct.signaling.pattern.gene(SpaCET_obj, n=3) ## End(Not run)
Calculate the signaling velocity of secreted proteins based on their activities.
SecAct.signaling.velocity.scST( SpaCET_obj, sender, secretedProtein, receiver, cellType_meta, scale.factor = 1e+05, CustomizedAreaCoordinates = NULL, radius = 20, colors_cellType = NULL )SecAct.signaling.velocity.scST( SpaCET_obj, sender, secretedProtein, receiver, cellType_meta, scale.factor = 1e+05, CustomizedAreaCoordinates = NULL, radius = 20, colors_cellType = NULL )
SpaCET_obj |
A SpaCET object. |
sender |
Sender cell types. |
secretedProtein |
Secreted proteins. |
receiver |
Receiver cell types. |
cellType_meta |
Column name in meta data that includes cell-type annotations. |
scale.factor |
Sets the scale factor for spot-level normalization. |
CustomizedAreaCoordinates |
Optional coordinates for customized area c(x.left, x.right, y.bottom, y.top). |
radius |
Radius cut off (unit: um). |
colors_cellType |
Named vector of colors for cell types. |
The velocity direction starts from the source cell producing a secreted protein and moves to sink cells receiving the secreted protein signal. The velocity magnitude represents the product between the secreted protein-coding gene expression at source cells and signaling activities at sink cells.
A ggplot2 object.
## Not run: SecAct.signaling.velocity.scST(SpaCET_obj, sender="Fibroblast", secretedProtein="THBS2", receiver="Tumor_boundary", cellType_meta="cellType") ## End(Not run)## Not run: SecAct.signaling.velocity.scST(SpaCET_obj, sender="Fibroblast", secretedProtein="THBS2", receiver="Tumor_boundary", cellType_meta="cellType") ## End(Not run)
Calculate the signaling velocity of secreted proteins based on their activities.
SecAct.signaling.velocity.spotST( SpaCET_obj, scale.factor = 1e+05, gene, signalMode = "receiving", radius = 200, contourMap = FALSE, coutourBins = 11, animated = FALSE )SecAct.signaling.velocity.spotST( SpaCET_obj, scale.factor = 1e+05, gene, signalMode = "receiving", radius = 200, contourMap = FALSE, coutourBins = 11, animated = FALSE )
SpaCET_obj |
A SpaCET object. |
scale.factor |
Sets the scale factor for spot-level normalization. |
gene |
Gene symbol coding a secreted protein. |
signalMode |
Mode of signaling velocity, i.e., "receiving", "sending", and "both". |
radius |
Radius cut off. |
contourMap |
A logical indicating whether transform as contour map. |
coutourBins |
Number of bins for contour map. |
animated |
A logical indicating whether generate animated figure. |
The velocity direction starts from the source cell producing a secreted protein and moves to sink cells receiving the secreted protein signal. The velocity magnitude represents the product between the secreted protein-coding gene expression at source cells and signaling activities at sink cells.
A ggplot2 object.
## Not run: SecAct.signaling.velocity.spotST(SpaCET_obj, gene="TGFB1", signalMode="receiving") SecAct.signaling.velocity.spotST(SpaCET_obj, gene="TGFB1", signalMode="sending") ## End(Not run)## Not run: SecAct.signaling.velocity.spotST(SpaCET_obj, gene="TGFB1", signalMode="receiving") SecAct.signaling.velocity.spotST(SpaCET_obj, gene="TGFB1", signalMode="sending") ## End(Not run)
Draw a survival plot of secreted proteins.
SecAct.survival.plot(mat, surv, gene, x.title = "Time")SecAct.survival.plot(mat, surv, gene, x.title = "Time")
mat |
Activity matrix. |
surv |
Survival matrix. |
gene |
Gene symbol. |
x.title |
Title for x axis. |
A ggplot2 object.